@@ -4,11 +4,10 @@
 #
 #
 import json
-import typing
 from typing import Type
 
 from mesh.codec.codec import Codec, T
-from mesh.macro import spi
+from mesh.macro import spi, Compatible
 
 Json = "json"
 
@@ -24,7 +23,7 @@ class JsonCodec(Codec):
         if value is None:
             return None
 
-        vt = typing.get_args(kind)
+        vt = Compatible.get_args(kind)
         if vt.__len__() < 1:
             return json.loads(value, cls=kind)
 
