@@ -56,7 +56,7 @@ class GrpcSession(Session):
     def push(self, payload: bytes, metadata: Dict[str, str], topic: str = ""):
         self.inbounds.put(payload)
 
-    def release(self, timeout: int):
+    def release(self, timeout: int, topic: str):
         pass
 
     def iter(self):
