@@ -51,7 +51,7 @@ class Registration:
         return {}
 
 
-class Metadata:
+class Resource:
 
     @index(0)
     def references(self) -> List[Reference]:
