@@ -88,22 +88,23 @@ class Session(ABC, Generic[T]):
 
     @abstractmethod
     @mpi("mesh.chan.release")
-    def release(self, timeout: int):
+    def release(self, timeout: int, topic: str):
         """
         Close the channel session.
         :param timeout:
+        :param topic: message topic
         :return:
         """
         pass
 
-    async def pick(self) -> bytes:
+    async def pick(self, topic: str = "") -> bytes:
         """ Peek the instance """
-        return self.peek()
+        return self.peek(topic)
 
-    async def poll(self, timeout: int) -> bytes:
+    async def poll(self, timeout: int, topic: str = "") -> bytes:
         """ Pop the instance """
-        return self.pop(timeout)
+        return self.pop(timeout, topic)
 
-    async def offer(self, payload: bytes):
+    async def offer(self, payload: bytes, metadata: Dict[str, str], topic: str = ""):
         """ Push the instance """
-        self.push(payload)
+        self.push(payload, metadata, topic)
