@@ -35,7 +35,7 @@ class MeshTransport(Transport):
     def close(self, timeout: int):
         for k, v in self.sessions.items():
             try:
-                v.release(timeout)
+                v.release(timeout, "")
             except BaseException as e:
                 log.error("", e)
 
@@ -97,5 +97,5 @@ class MeshSession(Session):
     def push(self, payload: bytes, metadata: Dict[str, str], topic: str = ""):
         return self.with_context(lambda: self.session.push(payload, metadata, topic), True, 0)
 
-    def release(self, timeout: int):
-        return self.with_context(lambda: self.session.release(timeout), False, timeout)
+    def release(self, timeout: int, topic: str):
+        return self.with_context(lambda: self.session.release(timeout, topic), False, timeout)
